    <!-- ***************************************************************************************************************
    *
    * Macro MavenRepoDownloadLink
    *
    **************************************************************************************************************** -->
    <xsl:template match="span[@class='nwXsltMacro_MavenRepoDownloadLink']">           
        <xsl:variable name="content">
            <xsl:apply-templates select="text()"/>
        </xsl:variable> 
        
        <xsl:element name="a">
            <xsl:attribute name="href">
                <xsl:call-template name="get-mavenrepo-artifact-download-url">
                    <xsl:with-param name="groupId" select="span[@class='nwXsltMacro_MavenRepoDownloadLink_groupId']"/>
                    <xsl:with-param name="artifactId" select="span[@class='nwXsltMacro_MavenRepoDownloadLink_artifactId']"/>
                    <xsl:with-param name="classifier" select="span[@class='nwXsltMacro_MavenRepoDownloadLink_classifier']"/>
                    <xsl:with-param name="type" select="span[@class='nwXsltMacro_MavenRepoDownloadLink_type']"/>
                </xsl:call-template>
            </xsl:attribute>
            <xsl:value-of select="$content" />                
        </xsl:element>
    </xsl:template>

    <!-- ***************************************************************************************************************
    *
    * Macro MavenRepoLatestVersion
    *
    **************************************************************************************************************** -->
    <xsl:template match="span[@class='nwXsltMacro_MavenRepoLatestVersion']">           
        <xsl:call-template name="get-latest-version">
            <xsl:with-param name="groupId" select="span[@class='nwXsltMacro_MavenRepoLatestVersion_groupId']"/>
            <xsl:with-param name="artifactId" select="span[@class='nwXsltMacro_MavenRepoLatestVersion_artifactId']"/>
        </xsl:call-template>
    </xsl:template>
    
    <!-- ***************************************************************************************************************
    *
    * Macro MavenMailingLists
    *
    **************************************************************************************************************** -->
    <xsl:template match="div[@class='nwXsltMacro_MavenMailingLists']">         
        <xsl:variable name="pomUrl">
            <xsl:call-template name="get-mavenrepo-artifact-download-url">
                <xsl:with-param name="groupId" select="p[@class='nwXsltMacro_MavenMailingLists_groupId']"/>
                <xsl:with-param name="artifactId" select="p[@class='nwXsltMacro_MavenMailingLists_artifactId']"/>
                <xsl:with-param name="type" select="'pom'"/>
            </xsl:call-template>
        </xsl:variable>
            
        <xsl:element name="table">
            <xsl:attribute name="class">
                <!-- TODO: drop zebra-striped and bordered-table when Bootstrap 1.4.0 support is no longer needed. -->
                <xsl:value-of select="'maven-mailing-lists zebra-striped bordered-table table table-striped table-bordered'"/>
            </xsl:attribute>            
            <xsl:element name="thead">
                <xsl:element name="tr">
                    <xsl:element name="td">
                        <xsl:value-of select="'Name'"/>
                    </xsl:element>
                    <xsl:element name="td">
                        <xsl:value-of select="'Address'"/>
                    </xsl:element>
                    <xsl:element name="td">
                        <xsl:value-of select="'Archive'"/>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
            <xsl:element name="tbody">
                <xsl:for-each select="document($pomUrl)/pom:project">                
                    <xsl:for-each select="pom:mailingLists/pom:mailingList">       
                        <xsl:element name="tr">
                            <xsl:element name="td">
                                <xsl:value-of select="pom:name"/>
                            </xsl:element>
                            <xsl:element name="td">
                                <xsl:element name="address">
                                    <xsl:element name="a">
                                        <xsl:attribute name="href">
                                            <xsl:value-of select="'mailto:'"/>
                                            <xsl:value-of select="pom:post"/>
                                        </xsl:attribute>
                                        <xsl:value-of select="pom:post"/>
                                    </xsl:element>
                                </xsl:element>
                            </xsl:element>
                            <xsl:element name="td">
                                <xsl:element name="a">
                                    <xsl:attribute name="href">
                                        <xsl:value-of select="pom:archive"/>
                                    </xsl:attribute>
                                    <xsl:value-of select="'Browse online'"/>
                                </xsl:element>
                            </xsl:element>
                        </xsl:element>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:element>
        </xsl:element>
    </xsl:template>
    
    <!-- ***************************************************************************************************************
    *
    * Macro MavenModulesTable
    *
    **************************************************************************************************************** -->
    <xsl:template match="div[@class='nwXsltMacro_MavenModulesTable']">         
        <xsl:variable name="pomUrl">
            <xsl:call-template name="get-mavenrepo-artifact-download-url">
                <xsl:with-param name="groupId" select="p[@class='nwXsltMacro_MavenModulesTable_groupId']"/>
                <xsl:with-param name="artifactId" select="p[@class='nwXsltMacro_MavenModulesTable_artifactId']"/>
                <xsl:with-param name="type" select="'pom'"/>
            </xsl:call-template>
        </xsl:variable>
            
        <xsl:element name="table">
            <xsl:attribute name="class">
                <!-- TODO: drop zebra-striped and bordered-table when Bootstrap 1.4.0 support is no longer needed. -->
                <xsl:value-of select="'maven-modules zebra-striped bordered-table table table-striped table-bordered'"/>
            </xsl:attribute>            
            <xsl:element name="thead">
                <xsl:text>&#10;</xsl:text>
                <xsl:element name="tr">
                    <xsl:element name="td">
                        <xsl:value-of select="'Module'"/>
                    </xsl:element>
                    <xsl:element name="td">
                        <xsl:value-of select="'Artifact ID'"/>
                    </xsl:element>
                    <xsl:element name="td">
                        <xsl:value-of select="'Status'"/>
                    </xsl:element>
                    <xsl:element name="td">
                        <xsl:value-of select="'Description'"/>
                    </xsl:element>
                </xsl:element>
            </xsl:element>

            <xsl:element name="tbody">
                <xsl:call-template name="emit-modules-description">
                    <xsl:with-param name="baseUrl">
                        <xsl:call-template name="get-scm-source-raw-base-url">
                            <xsl:with-param name="pomUrl">
                                <xsl:value-of select="$pomUrl"/>
                            </xsl:with-param>
                        </xsl:call-template>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:element>
        </xsl:element>
    </xsl:template>
    
    <!-- ***************************************************************************************************************
    *
    * Macro SourceRepoDownloadLink
    *
    **************************************************************************************************************** -->
    <xsl:template match="span[@class='nwXsltMacro_SourceRepoDownloadLink']">         
        <xsl:variable name="pomUrl">
            <xsl:call-template name="get-mavenrepo-artifact-download-url">
                <xsl:with-param name="groupId" select="span[@class='nwXsltMacro_SourceRepoDownloadLink_groupId']"/>
                <xsl:with-param name="artifactId" select="span[@class='nwXsltMacro_SourceRepoDownloadLink_artifactId']"/>
                <xsl:with-param name="type" select="'pom'"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:variable name="content">
            <xsl:apply-templates select="text()"/>
        </xsl:variable> 
        
        <xsl:element name="a">
            <xsl:attribute name="href">
                <xsl:call-template name="get-scm-source-tarball-url">
                    <xsl:with-param name="pomUrl" select="$pomUrl"/>
                </xsl:call-template>
            </xsl:attribute>
            <xsl:value-of select="$content" />                
        </xsl:element>
    </xsl:template>

    <!-- ***************************************************************************************************************
    *
    * Macro SourceRepoBrowseLink
    *
    **************************************************************************************************************** -->
    <xsl:template match="span[@class='nwXsltMacro_SourceRepoBrowseLink']">         
        <xsl:variable name="pomUrl">
            <xsl:call-template name="get-mavenrepo-artifact-download-url">
                <xsl:with-param name="groupId" select="span[@class='nwXsltMacro_SourceRepoBrowseLink_groupId']"/>
                <xsl:with-param name="artifactId" select="span[@class='nwXsltMacro_SourceRepoBrowseLink_artifactId']"/>
                <xsl:with-param name="type" select="'pom'"/>
            </xsl:call-template>
        </xsl:variable>
            
        <xsl:variable name="content">
            <xsl:apply-templates select="text()"/>
        </xsl:variable> 
        
        <xsl:element name="a">
            <xsl:attribute name="href">
                 <xsl:call-template name="get-scm-source-browse-url">
                    <xsl:with-param name="pomUrl" select="$pomUrl"/>
                </xsl:call-template>
            </xsl:attribute>
            <xsl:value-of select="$content" />                
        </xsl:element>
    </xsl:template>
    
    <!-- ***************************************************************************************************************
    *
    * Macro SourceCheckout
    *
    **************************************************************************************************************** -->
    <xsl:template match="div[@class='nwXsltMacro_SourceCheckout']">         
        <xsl:variable name="pomUrl">
            <xsl:call-template name="get-mavenrepo-artifact-download-url">
                <xsl:with-param name="groupId" select="p[@class='nwXsltMacro_SourceCheckout_groupId']"/>
                <xsl:with-param name="artifactId" select="p[@class='nwXsltMacro_SourceCheckout_artifactId']"/>
                <xsl:with-param name="type" select="'pom'"/>
            </xsl:call-template>
        </xsl:variable>
            
        <xsl:element name="pre">
            <xsl:for-each select="document($pomUrl)/pom:project">                
                <xsl:text>hg clone </xsl:text>
                <xsl:value-of select="pom:properties/pom:scm.repo.readonly.url"/>
                <xsl:text>&#10;hg up -C </xsl:text>
                <xsl:value-of select="pom:version"/>
            </xsl:for-each>
        </xsl:element>
    </xsl:template>
